@@ -1,3 +1,5 @@
+# https://github.com/tidymodels/tune/blob/main/R/tune_grid.R
+
 #' Model tuning via grid search
 #'
 #' [tune_cluster()] computes a set of performance metrics (e.g. accuracy or
@@ -282,6 +284,7 @@ tune_cluster_loop <- function(resamples,
   resamples
 }
 
+# https://github.com/tidymodels/tune/blob/main/R/grid_helpers.R#L299
 compute_grid_info <- function(workflow, grid) {
   if (is.null(grid)) {
     out <- new_grid_info_resamples()
@@ -371,11 +374,7 @@ tune_cluster_loop_iter <- function(split,
   # Nest grid_info:
   # - Preprocessor info in the outer level
   # - Model info in the inner level
-  if (tidyr_new_interface()) {
-    grid_info <- tidyr::nest(grid_info, data = !!cols)
-  } else {
-    grid_info <- tidyr::nest(grid_info, !!cols)
-  }
+  grid_info <- tidyr::nest(grid_info, data = !!cols)
 
   training <- rsample::analysis(split)
 
@@ -401,7 +400,7 @@ tune_cluster_loop_iter <- function(split,
 
     iter_msg_preprocessor <- iter_grid_info[[".msg_preprocessor"]]
 
-    workflow <- finalize_workflow_preprocessor(
+    workflow <- tune::finalize_workflow_preprocessor(
       workflow = workflow,
       grid_preprocessor = iter_grid_preprocessor
     )
@@ -591,7 +590,7 @@ tune_cluster_loop_iter_safely <- function(split,
   result
 }
 
-
+# https://github.com/tidymodels/tune/blob/main/R/grid_code_paths.R#L542
 super_safely <- function(fn) {
   warnings <- list()
   handle_error <- function(e) {
@@ -617,6 +616,7 @@ super_safely <- function(fn) {
   safe_fn
 }
 
+# https://github.com/tidymodels/tune/blob/main/R/grid_helpers.R#L428
 compute_grid_info_model <- function(workflow, grid, parameters_model) {
   spec <- extract_spec_parsnip(workflow)
   out <- min_grid(spec, grid)
@@ -652,17 +652,14 @@ compute_grid_info_model <- function(workflow, grid, parameters_model) {
   out
 }
 
+# https://github.com/tidymodels/tune/blob/main/R/grid_helpers.R#L484
 compute_grid_info_model_and_preprocessor <- function(workflow,
                                                      grid,
                                                      parameters_model) {
   parameter_names_model <- parameters_model[["id"]]
 
   # Nest model parameters, keep preprocessor parameters outside
-  if (tidyr_new_interface()) {
-    out <- tidyr::nest(grid, data = dplyr::all_of(parameter_names_model))
-  } else {
-    out <- tidyr::nest(grid, dplyr::all_of(parameter_names_model))
-  }
+  out <- tidyr::nest(grid, data = dplyr::all_of(parameter_names_model))
 
   n_preprocessors <- nrow(out)
   seq_preprocessors <- seq_len(n_preprocessors)
@@ -742,6 +739,7 @@ compute_grid_info_model_and_preprocessor <- function(workflow,
   out
 }
 
+# https://github.com/tidymodels/tune/blob/main/R/grid_helpers.R#L359
 compute_grid_info_preprocessor <- function(workflow,
                                            grid,
                                            parameters_model) {
@@ -811,6 +809,7 @@ compute_grid_info_preprocessor <- function(workflow,
   out
 }
 
+# https://github.com/tidymodels/tune/blob/main/R/checks.R#L338
 check_metrics <- function(x, object) {
   mode <- extract_spec_parsnip(object)$mode
 
@@ -846,6 +845,7 @@ check_metrics <- function(x, object) {
   x
 }
 
+# https://github.com/tidymodels/tune/blob/main/R/checks.R#L144
 check_parameters <- function(workflow,
                              pset = NULL,
                              data,
@@ -899,6 +899,7 @@ needs_finalization <- function(x, nms = character(0)) {
   any(dials::has_unknowns(x$object))
 }
 
+# https://github.com/tidymodels/tune/blob/main/R/checks.R#L274
 check_workflow <- function(x, pset = NULL, check_dials = FALSE) {
   if (!inherits(x, "workflow")) {
     rlang::abort("The `object` argument should be a 'workflow' object.")
@@ -909,7 +910,7 @@ check_workflow <- function(x, pset = NULL, check_dials = FALSE) {
   }
 
   if (!has_spec(x)) {
-    rlang::abort("A parsnip model is required.")
+    rlang::abort("A tidyclust model is required.")
   }
 
   if (check_dials) {
@@ -935,6 +936,7 @@ check_workflow <- function(x, pset = NULL, check_dials = FALSE) {
   invisible(NULL)
 }
 
+# https://github.com/tidymodels/tune/blob/main/R/checks.R#L257
 check_param_objects <- function(pset) {
   params <- map_lgl(pset$object, inherits, "param")
 
@@ -950,6 +952,7 @@ check_param_objects <- function(pset) {
 
 grid_msg <- "`grid` should be a positive integer or a data frame."
 
+# https://github.com/tidymodels/tune/blob/main/R/checks.R#L36
 check_grid <- function(grid, workflow, pset = NULL) {
   # `NULL` grid is the signal that we are using `fit_resamples()`
   if (is.null(grid)) {
