@@ -1,9 +1,10 @@
 test_that("reconciliation works with one-to-one", {
-  primary_cluster_assignment <- c("Apple", "Apple", "Carrot", "Carrot",
-                                  "Banana", "Banana")
+  primary_cluster_assignment <- c(
+    "Apple", "Apple", "Carrot", "Carrot",
+    "Banana", "Banana"
+  )
   alt_cluster_assignment <- c("Dog", "Dog", "Cat", "Dog", "Fish", "Fish")
 
-
   res <- reconcile_clusterings_mapping(
     primary_cluster_assignment,
     alt_cluster_assignment
@@ -16,11 +17,12 @@ test_that("reconciliation works with one-to-one", {
 })
 
 test_that("reconciliation works with uneven numbers", {
-  primary_cluster_assignment <- c("Apple", "Apple", "Carrot", "Carrot",
-                                  "Banana", "Banana")
+  primary_cluster_assignment <- c(
+    "Apple", "Apple", "Carrot", "Carrot",
+    "Banana", "Banana"
+  )
   alt_cluster_assignment <- c("Dog", "Dog", "Cat", "Dog", "Parrot", "Fish")
 
-
   expect_snapshot(
     error = TRUE,
     reconcile_clusterings_mapping(
